@@ -1,22 +1,51 @@
+utils::globalVariables("where")
+#utils::globalVariables("any_of")
+#utils::globalVariables("if_all")
+
 #' @import stats
 #' @import dimensionsR
 #' @import ggplot2
 #' @import bibliometrixData
+#' @import forcats
 #' @import ggrepel
-#' @import ggraph
+#' @import ggnetwork
 #' @import pubmedR
 #' @import shiny
+#' @import readr
+#' @import readxl
+#' @import tidytext
+#' @importFrom plotly add_annotations
+#' @importFrom plotly add_lines
+#' @importFrom plotly config
+#' @importFrom plotly ggplotly
+#' @importFrom plotly layout
+#' @importFrom plotly plot_ly
+#' @importFrom plotly subplot
+#' @importFrom plotly toRGB
 # #' @import shinycssloaders
 # #' @import shinythemes
+#' @importFrom openxlsx write.xlsx
 #' @importFrom tidyr gather
 #' @importFrom tidyr spread
 #' @importFrom tidyr pivot_wider
 #' @importFrom tidyr pivot_longer
+#' @importFrom tidyr replace_na
+#' @importFrom tidyr separate
+#' @importFrom tidyr drop_na
+#' @importFrom tidyr unite
+#' @importFrom tidyr starts_with
+# @importFrom tidyselect where
 #' @importFrom grDevices adjustcolor
 #' @importFrom dplyr %>%
+#' @importFrom dplyr across
 #' @importFrom dplyr tibble
+#' @importFrom dplyr as_tibble
+#' @importFrom dplyr between
 # @importFrom dplyr filter
 #' @importFrom dplyr arrange
+#' @importFrom dplyr if_all
+#' @importFrom dplyr any_of
+#' @importFrom dplyr cummean
 #' @importFrom dplyr desc
 #' @importFrom dplyr group_by
 #' @importFrom dplyr mutate
@@ -29,12 +58,16 @@
 #' @importFrom dplyr anti_join
 #' @importFrom dplyr inner_join
 #' @importFrom dplyr left_join
+#' @importFrom dplyr right_join
 #' @importFrom dplyr top_n
+#' @importFrom dplyr relocate
+#' @importFrom dplyr slice_head
+#' @importFrom dplyr slice_tail
 #' @importFrom grDevices dev.off
 #' @importFrom grDevices pdf
-#' @importFrom networkD3 sankeyNetwork
-#' @importFrom networkD3 sankeyNetworkOutput
-#' @importFrom networkD3 renderSankeyNetwork
+# @importFrom networkD3 sankeyNetwork
+# @importFrom networkD3 sankeyNetworkOutput
+# @importFrom networkD3 renderSankeyNetwork
 #' @importFrom DT DTOutput
 #' @importFrom DT renderDT
 #' @importFrom DT datatable
@@ -217,22 +250,28 @@
 #' @importFrom Matrix writeMM
 #' @importFrom stringr str_locate_all
 #' @importFrom stringr str_extract_all
-# @importFrom stringr str_replace
+#' @importFrom stringr str_replace_all
 #' @importFrom graphics barplot
 #' @importFrom graphics legend
 #' @importFrom graphics lines
 #' @importFrom graphics plot
 #' @importFrom graphics par
+#' @importFrom grDevices colorRampPalette
+#' @importFrom grDevices as.raster
 #' @importFrom utils capture.output
 #' @importFrom utils data
 #' @importFrom utils adist
 #' @importFrom utils read.csv
 #' @importFrom SnowballC wordStem
 #' @importFrom SnowballC getStemLanguages
-#' @importFrom rio import
+# @importFrom rio import
 .onAttach<-function(...){
-  packageStartupMessage("To cite bibliometrix in publications, please use:\n\nAria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier.
-                        \n\nhttp:\\\\www.bibliometrix.org\n
+  packageStartupMessage("To cite bibliometrix in publications, please use:\n\nAria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, 
+                                 Journal of Informetrics, 11(4), pp 959-975, Elsevier.
+                        \n\nhttps://www.bibliometrix.org\n
+                        \nFor information and bug reports:
+                        - Send an email to info@bibliometrix.org   
+                        - Write a post on https://github.com/massimoaria/bibliometrix/issues
                         \nHelp us to keep Bibliometrix free to download and use by contributing with a small donation to support our research team (https://bibliometrix.org/donate.html)\n
                         \nTo start with the shiny web-interface, please digit:
 biblioshiny()\n")
